from setuptools import setup

setup(name='dsnd_probabilities_udacity',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['dsnd_probabilities_udacity'],
      author = 'Sifat Nabil',
      author_email = 'sifatnabil@gmail.com',
      zip_safe=False)
